#!/bin/sh
#\
exec expectk524 -f "$0" -- "$@"

wm withdraw .

#Prefs
#This procedure is used to give a standard appearance to the GUI.
#All colours and texts are set from the prefs array so they can all
#be changed quickly in a single action.
proc prefs { } {

   global prefs

   set prefs(fg)       Black
   set prefs(bg)       gray80
   set prefs(lst_fg)         Black
   set prefs(lst_bg)      gray80
   set prefs(label_fg)       Black
   set prefs(label_bg)       gray80
   set prefs(entry_fg)       Black
   set prefs(entry_bg)       White
   set prefs(text_fg)        Black
   set prefs(text_bg)        white
   set prefs(button_fg)      Black
   set prefs(button_bg)      gray80
   set prefs(frame_fg)       Black
   set prefs(frame_bg)       gray80
   set prefs(radio_fg)       Black
   set prefs(radio_bg)       gray80
   set prefs(status_bg)      #0000ff
   set prefs(status_fg)      #ffff00
   set prefs(error)    red
   set prefs(entry_font)     -*-helvetica-bold-r-*-*-12-*;#{times 10 bold}
   set prefs(button_font)    -*-helvetica-bold-r-*-*-12-*;#{times 10 bold}
   set prefs(label_font)     -*-helvetica-bold-r-*-*-12-*;#{times 10 bold}
   set prefs(txt_font)       -*-helvetica-bold-r-*-*-14-*;#{times 12 bold}
   set prefs(lst_font)       {times 12 bold}
}

prefs

set i 0
set colours(gray80) 0
set colours(red) 1
set colours(green) 2
set colours(orange) 3
set ReadFile "response.io"
set WriteFile "instruct.io"
set sw1_value 0
set sw2_value 1
set sw3_value 1

proc gui {title} {

   global prefs buttons gui LedColour prog colours ReadFile \
   sw1_value sw2_value sw3_value
   
   set reset 1

   set gui [ toplevel .gui ]
   wm focusmodel $gui passive
   wm geometry $gui 300x400+200+200
   wm maxsize $gui 300 400
   wm minsize $gui 1 1
   wm overrideredirect $gui 0
   wm resizable $gui 0 0
   wm deiconify $gui
   wm title $gui "$title"

   frame $gui.top \
      -borderwidth 2\
      -relief groove \
      -bg $prefs(frame_bg)
   place $gui.top \
      -x 0 -y 0 \
      -width 300 \
      -height 400 \
      -anchor nw \
      -bordermode ignore

   button $gui.top.close \
      -padx 11 \
      -pady 4 \
      -fg $prefs(button_fg) \
      -bg $prefs(button_bg)  \
      -font $prefs(button_font)\
      -text "Close" \
      -command {destroy widget .gui}
   place $gui.top.close \
      -x 10 -y 390 \
      -width 90 \
      -height 25 \
      -anchor sw \
      -bordermode ignore

   frame $gui.top.led \
      -borderwidth 2\
      -relief sunken \
      -bg $prefs(frame_bg)
   place $gui.top.led \
      -x 10 -y 10 \
      -width 280 \
      -height 250 \
      -anchor nw \
      -bordermode ignore


   label $gui.top.led.lb \
      -text "LEDs" \
      -font $prefs(entry_font) \
      -background $prefs(label_bg) \
      -foreground $prefs(label_fg) \
      -width 25 \
      -justify left \
      -relief ridge
   place $gui.top.led.lb \
      -x 140 -y 10 \
      -anchor n \
      -bordermode ignore

   set y 75
   for {set j 1} {$j < 9} {incr j 3} {
      set x 70
      for {set i $j} {$i < [expr $j + 3]} {incr i} {
         label $gui.top.led.ledlb$i \
            -text "LED$i" \
            -font $prefs(txt_font) \
            -background $prefs(label_bg) \
            -foreground $prefs(label_fg) \
            -justify center \
            -relief flat
         place $gui.top.led.ledlb$i  \
            -x [expr $x-5] -y $y  \
            -height 20 \
            -anchor e \
            -bordermode ignore

         set leds($i) [label $gui.top.led.led$i \
            -background $prefs(bg) \
            -justify center \
            -relief raised \
            -height 1 \
            -width 2 ]
         place $gui.top.led.led$i  \
            -x $x -y $y \
            -height 20 \
            -anchor w \
            -bordermode ignore

         incr x 80

         set LedColour($i) $prefs(bg)

         bind $gui.top.led.led$i <ButtonRelease-1> {
            regexp "led(\[0-9])" %W x numb
            switch $LedColour($numb) {
               gray80 {set LedColour($numb) green}
               red {set LedColour($numb) orange}
               green {set LedColour($numb) $prefs(bg)}
               orange {set LedColour($numb) red}
            }
            %W config -bg $LedColour($numb)
            setLED $numb $colours($LedColour($numb))
         }
         bind $gui.top.led.led$i <ButtonRelease-3> {
            regexp "led(\[0-9])" %W x numb
            switch $LedColour($numb) {
               gray80 {set LedColour($numb) red}
               red {set LedColour($numb) $prefs(bg)}
               green {set LedColour($numb) orange}
               orange {set LedColour($numb) green}
            }
            %W config -bg $LedColour($numb)
            setLED $numb $colours($LedColour($numb))
         }
      
      }

   incr y 55
   }     

   button $gui.top.led.clear \
      -padx 11 \
      -pady 4 \
      -fg $prefs(button_fg) \
      -bg $prefs(button_bg)  \
      -font $prefs(button_font)\
      -text "Clear" \
      -command {ClearLED}
   place $gui.top.led.clear \
      -x 275 -y 245 \
      -width 90 \
      -height 25 \
      -anchor se \
      -bordermode ignore   

   label $gui.top.sw1_lb \
      -text "SW 1" \
      -font $prefs(txt_font) \
      -background $prefs(label_bg) \
      -foreground $prefs(label_fg) \
      -justify center \
      -relief flat
   place $gui.top.sw1_lb  \
      -x 80 -y 315  \
      -height 20 \
      -anchor e \
      -bordermode ignore

   label $gui.top.sw1 \
      -background $prefs(bg) \
      -justify center \
      -relief raised \
      -height 1 \
      -width 2
   place $gui.top.sw1  \
      -x 80 -y 315 \
      -height 20 \
      -anchor w \
      -bordermode ignore

   label $gui.top.sw2_lb \
      -text "SW 2" \
      -font $prefs(txt_font) \
      -background $prefs(label_bg) \
      -foreground $prefs(label_fg) \
      -justify center \
      -relief flat
   place $gui.top.sw2_lb  \
      -x 160 -y 315  \
      -height 20 \
      -anchor e \
      -bordermode ignore

   label $gui.top.sw2 \
      -background $prefs(bg) \
      -justify center \
      -relief raised \
      -height 1 \
      -width 2
   place $gui.top.sw2  \
      -x 160 -y 315 \
      -height 20 \
      -anchor w \
      -bordermode ignore

   label $gui.top.sw3_lb \
      -text "SW 3" \
      -font $prefs(txt_font) \
      -background $prefs(label_bg) \
      -foreground $prefs(label_fg) \
      -justify center \
      -relief flat
   place $gui.top.sw3_lb  \
      -x 240 -y 315  \
      -height 20 \
      -anchor e \
      -bordermode ignore

   label $gui.top.sw3 \
      -background $prefs(bg) \
      -justify center \
      -relief raised \
      -height 1 \
      -width 2
   place $gui.top.sw3  \
      -x 240 -y 315 \
      -height 20 \
      -anchor w \
      -bordermode ignore

   set prog [open "|{C:/Program Files/XJTAG 2.1/bin/XJDebug.exe} -set gSwitch=1 -run {C:/test/gui/demo_board_file.xje}" r+]

   while {[winfo exist .gui]} {
      set x 0
      set rfile 0
      set alm 0
      set intdir 0
      if {[catch {open $ReadFile r} rfile] == 0} {
         gets $rfile line
         regexp "SETTINGS :(\[0-1]):(\[0-1]):(\[0-1])" $line x sw1_value sw2_value sw3_value
         if {$sw1_value == 0} {
            $gui.top.sw1 config -bg $prefs(bg)
         } else {$gui.top.sw1 config -bg green}
         if {$sw2_value == 1} {
            $gui.top.sw2 config -bg $prefs(bg)
         } else {$gui.top.sw2 config -bg green}
         if {$sw3_value == 1} {
            $gui.top.sw3 config -bg $prefs(bg)
         } else {$gui.top.sw3 config -bg green}
         close $rfile 
      }
      after 160 {set x 1}
      vwait x
   }
   setexit
   catch {close $prog}
   
}


proc setLED {numb colour} {
   global WriteFile CurrentDir direction
   set wfile [open $WriteFile w]
   puts -nonewline $wfile "LED$numb!$colour"
   close $wfile
}
   
proc ClearLED {} {
   global WriteFile LedColour gui prefs
   set wfile [open $WriteFile w]
   for {set i 1} {$i < 9} {incr i} {
      $gui.top.led.led$i config -bg $prefs(bg)
      set LedColour($i) $prefs(bg)
      puts $wfile "LED$i!0"
   }
   $gui.top.led.led9 config -bg $prefs(bg)
   set LedColour(9) $prefs(bg)   
   puts -nonewline $wfile "LED9!0"
   close $wfile
}
   
proc setexit {} {
   global WriteFile
   set wfile [open $WriteFile w]
   puts -nonewline $wfile "exit!"
   close $wfile
}

catch {file delete -force $ReadFile}
catch {file delete -force $WriteFile}
gui "XJTAG Demo Board GUI"
catch {file delete -force $ReadFile}
catch {file delete -force $WriteFile}


exit